<template>
  <el-dialog
    v-diadrag
    :title="!dataForm.id ? '新增' : '修改'"
    :close-on-click-modal="false"
    :visible.sync="visible"
  >
    <el-form
      :model="dataForm"
      :rules="dataRule"
      ref="dataForm"
      label-width="80px"
      class="l-mes"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="仓库编号" prop="warehouseNo">
            <el-input
              v-model="dataForm.warehouseNo"
              placeholder="仓库编号"
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="仓库名称" prop="warehouseName">
            <el-input
              v-model="dataForm.warehouseName"
              placeholder="仓库名称"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="仓库描述" prop="warehouseDesc">
            <el-input
              v-model="dataForm.warehouseDesc"
              placeholder="仓库描述"
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="仓库类型" prop="warehouseType">
            <el-select
              v-model="dataForm.warehouseType"
              placeholder="仓库类型"
              filterable
              style="width: 100%"
            >
              <el-option
                v-for="item in warehouseTypeOption"
                :key="item.id"
                :label="item.label"
                :value="item.value"
              />
            </el-select>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="工厂" prop="factoryId">
            <el-select disabled
              v-model="dataForm.factoryId"
              filterable
              placeholder="请选择"
              style="width:100%"
            >
              <el-option
                v-for="(item, index) in this.factoryOptions"
                :label="item.factoryName"
                :value="item.id"
                :key="index"
              >
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="仓库地址" prop="warehouseAddr">
            <el-input
              v-model="dataForm.warehouseAddr"
              placeholder="仓库地址"
            ></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="备注" prop="warehouseRemark">
            <el-input
              v-model="dataForm.warehouseRemark"
              placeholder="备注"
            ></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="创建时间" prop="createTime">
            <el-date-picker
              readonly
              style="width: 100%"
              v-model="moment"
              type="datetime"
              placeholder="选择日期时间"
              value-format="yyyy-MM-dd HH:mm:ss"
            >
            </el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="仓库地图" prop="warehouseMap">
            <el-upload
              ref="upload"
              action="/mes/warehouse/upload"
              :headers="headers"
              accept="image/jpeg,image/jpg,image/"
              :limit="limitNum"
              :auto-upload="true"
              :on-exceed="exceedFile"
              :file-list="fileList"
              list-type="picture"
              :on-success="onSuccess"
              :on-remove="handleRemove"
              :on-preview="handlePreview"
              :with-credentials="true"
            >
              <el-button size="small" type="primary">点击上传</el-button>
              <div slot="tip" class="el-upload__tip">
                只能上传jpg/png文件，且不超过500kb
              </div>
            </el-upload>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="仓库状态" prop="warehouseStatus">
            <el-switch
              v-model="dataForm.warehouseStatus"
              :active-value="1"
              :inactive-value="0"
            ></el-switch>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <span slot="footer" class="dialog-footer">
      <el-button @click="visible = false">取消</el-button>
      <el-button
        type="primary"
        :disabled="isSubmit"
        v-thinclick="`dataFormSubmit`"
        >确定</el-button
      >
    </span>
  </el-dialog>
</template>

<script>
import { getElPosition } from '@/util/elAttr.js'
import { getObj, addObj, putObj } from '@/api/warehouse/warehouse'
import { remote } from '../../../api/admin/dict'
import { loadFactoryList } from '@/api/basic/factory'
import {
  delFiled,
  getFiled,
  removeFile
} from '../../../api/warehouse/warehouse'
import { getStore } from '../../../util/store'
export default {
  data() {
    return {
      warehouseFileName: '',
      warehouseUrl: '',
      limitNum: 1,
      mes: 'mes',
      fileList: [],
      moment: '',
      visible: false,
      factoryOptions: [],
      warehouseTypeOption: [],
      warehouseOption: [],
      dataForm: {
        id: 0,
        url: '',
        warehouseNo: '',
        warehouseName: '',
        warehouseDesc: '',
        warehouseType: '',
        factoryId: 117,
        warehouseAddr: '',
        warehouseMap: '',
        warehouseStatus: '',
        warehouseRemark: '',
        createTime: ''
      },
      headers: {
        Authorization: 'Bearer ' + getStore({ name: 'access_token' })
      },
      dataRule: {
        warehouseNo: [
          { required: true, message: '仓库编号不能为空', trigger: 'blur' }
        ],
        warehouseName: [
          { required: true, message: '仓库名称不能为空', trigger: 'blur' }
        ],
        warehouseType: [
          { required: true, message: '仓库类型不能为空', trigger: 'blur' }
        ],
        factoryId: [
          { required: true, message: '工厂不能为空', trigger: 'blur' }
        ],
        warehouseStatus: [
          { required: true, message: '仓库状态不能为空', trigger: 'blur' }
        ]
      },
      isSubmit: false
    }
  },
  created() {
    this.getWarehouse()
    this.initFactorySelect()
  },
  methods: {
    getDataTime() {
      this.moment = new Date()
    },
    getWarehouse() {
      remote('storehouse_type').then((response) => {
        if (response.data.code === 0) {
          this.warehouseTypeOption = response.data.data
        }
      })
    },
    init(id) {
      this.getDataTime()
      this.dataForm.id = id || 0
      this.fileList = []
      this.warehouseUrl = null
      this.visible = true
      this.$nextTick(() => {
        this.$refs.dataForm.resetFields()
        if (this.dataForm.id) {
          getObj(this.dataForm.id).then((response) => {
            this.dataForm = []
            this.fileList = []
            this.dataForm = response.data.data
            this.moment = this.dataForm.createTime
            if (this.dataForm.url) {
              var fileEl
              fileEl = {}
              fileEl.name = this.dataForm.url
              fileEl.fileName = this.dataForm.warehouseMap
              this.warehouseUrl = this.dataForm.url
              this.fileList.push(fileEl)
            }
            // getFiled(this.mes,this.dataForm.warehouseMap).then(response => {
            // })
          })
        }
      })
    },
    handleRemove(file, fileList) {
      if (this.dataForm.warehouseMap) {
        removeFile(
          Object.assign({
            fileName: file.fileName
          })
        ).then((response) => {})
        delFiled(this.dataForm.id).then((response) => {})
        this.$emit('refreshDataList')
      } else {
        removeFile(
          Object.assign({
            fileName: file.response.data.fileName
          })
        ).then((response) => {})
      }
      this.warehouseUrl = ''
      this.warehouseFileName = ''
    },
    handlePreview(file) {
      if (this.dataForm.warehouseMap) {
        window.open(file.name)
      } else {
        window.open(file.response.data.url)
      }
    },
    // 获取工厂的数据
    initFactorySelect() {
      loadFactoryList().then((res) => {
        this.factoryOptions = res.data
      })
    },
    // 文件上传成功时的钩子
    onSuccess(res, file, fileList) {
      this.warehouseFileName = file.response.data.fileName
      this.warehouseUrl = file.response.data.url
      this.$notify.success({
        title: '成功',
        message: '文件上传成功'
      })
    },
    exceedFile(files, fileList) {
      this.$notify.warning({
        title: '警告',
        message: `只能选择 ${
          this.limitNum
        } 个文件，当前共选择了 ${files.length + fileList.length} 个`
      })
    },
    // 表单提交
    dataFormSubmit() {
      this.isSubmit = true
      this.$refs.dataForm.validate((valid) => {
        if (valid) {
          this.dataForm.warehouseMap = this.warehouseFileName
          this.dataForm.url = this.warehouseUrl
          if (this.dataForm.id) {
            putObj(this.dataForm).then((data) => {
              this.$message.success('修改成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          } else {
            addObj(this.dataForm).then((data) => {
              this.$message.success('添加成功')
              this.visible = false
              this.isSubmit = false
              this.$emit('refreshDataList')
            })
          }
        } else {
          this.isSubmit = false
        }
      })
    }
  }
}
</script>
